---
layout: page
permalink: /resources/
title: External Resources
---


Samples:
- [counter](http://ajanse.me/asciidots/demo/?code=%20%20%20%20%20%2F1%23-.%0A%20%20%20%20%20%7C%0A%20%20%20%2F-%2B-%24%23%5C%0A%20%20%20%7C%20%7C%20%20%20%7C%0A%20%20%5B%2B%5D%3C1%23-*%0A%20%20%20%7C%20%20%20%20%20%7C%0A%20%20%20%5C--%3C--%2F%0A%20%20%20%20%20%20%7C%0A%20%20%20%20%20%200%0A%20%20%20%20%20%20%23%0A%20%20%20%20%20%20%7C%0A%20%20%20%20%20%20.)
- [quine](http://ajanse.me/asciidots/demo/?code=(%24%27.-%2340-%24_a%23-%2336-%24_a%23-%2339-%24_a%23))
- [factorial](http://ajanse.me/asciidots/demo/?code=%20%2F---------*--~-%24%23-%26%0A%20%7C%20%2F--%3B---%5C%7C%20%5B!%5D-%5C%0A%20%7C%20*------%2B%2B--*%231%2F%0A%20%7C%20%7C%20%2F1%23%5C%20%7C%7C%0A%5B*%5D*%7B-%7D-*~%3C%2B*%3F%23-.%0A%20*-------%2B-%3C%2F%0A%20%5C-%230----%2F)


Projects built for AsciiDots:
- [ddorn/vs-asciidots](https://github.com/ddorn/vs-asciidots)
  A Visual Studio syntax highlighter for AsciiDots.
- [ddorn/AsciidotsDebugger](https://github.com/ddorn/AsciidotsDebugger)
  A wonderful pygame debugger for AsciiDots. Supports zoom, pan, hovering with mouse for dot info, moving backwards through time, and more.
- [PiMan100111010/AsciiDots-application](https://github.com/PiMan100111010/AsciiDots-application)
  macos AsciiDots application
- [Scibuild/dots-esolang](https://github.com/Scibuild/dots-esolang)
  AsciiDots support for the Atom text editor

AsciiDots variants:
- [holtchesley/unicodots](https://github.com/holtchesley/unicodots)
  Unicode version of AsciiDots.
- [aaronjanse/marble-complete](https://github.com/aaronjanse/marble-complete)
  Simulate Turing-complete marble towers using modified AsciiDots syntax.

Alternate AsciiDots implementations:
- [kqo/asciidots-sharp](https://github.com/kqo/asciidots-sharp)
  C# AsciiDots implementation

Misc:
- [francois2metz/docker-asciidots](https://github.com/francois2metz/docker-asciidots)
  Run AsciiDots in a docker container
- [tio.run/#asciidots](https://tio.run/#asciidots)
  Try AsciiDots online with TIO's standard interface (great for [ppcg](https://codegolf.stackexchange.com/) submissions)

Feel free to edit this or open an issue if you create a project for/using AsciiDots.

